@@ -1,32 +1,33 @@
 /*
  *  Copyright 2013  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License or (at your option) version 3 or any later version
- *  accepted by the membership of KDE e.V. (or its successor approved
- *  by the membership of KDE e.V.), which shall act as a proxy
- *  defined in Section 14 of version 3 of the license.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) version 3, or any
+ *  later version accepted by the membership of KDE e.V. (or its
+ *  successor approved by the membership of KDE e.V.), which shall
+ *  act as a proxy defined in Section 6 of version 3 of the license.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "learninggoalmodel.h"
 #include "profilemanager.h"
 #include "learner.h"
 
+#include <QAbstractItemModel>
 #include <QAbstractListModel>
 #include <QSignalMapper>
 
-#include <KLocale>
-#include <KDebug>
+#include <KLocalizedString>
+#include "liblearner_debug.h"
 
 using namespace LearnerProfile;
 
@@ -88,12 +89,6 @@ LearningGoalModel::LearningGoalModel(QObject *parent)
     : QAbstractListModel(parent)
     , d(new LearningGoalModelPrivate)
 {
-    QHash<int, QByteArray> roles;
-    roles[TitleRole] = "title";
-    roles[IdRole] = "id";
-    roles[DataRole] = "dataRole";
-    setRoleNames(roles);
-
     connect(d->m_signalMapper, SIGNAL(mapped(int)), SLOT(emitLearningGoalChanged(int)));
 }
 
@@ -102,6 +97,16 @@ LearningGoalModel::~LearningGoalModel()
 
 }
 
+QHash< int, QByteArray > LearningGoalModel::roleNames() const
+{
+    QHash<int, QByteArray> roles;
+    roles[TitleRole] = "title";
+    roles[IdRole] = "id";
+    roles[DataRole] = "dataRole";
+
+    return roles;
+}
+
 void LearningGoalModel::setProfileManager(ProfileManager *profileManager)
 {
     if (d->m_profileManager == profileManager) {
@@ -209,7 +214,7 @@ void LearningGoalModel::onLearningGoalAboutToBeRemoved(int index)
     }
 
     if (index < 0 || d->m_goals.count() <= index) {
-        kWarning() << "Cannot remove learning goal from model, not registered";
+        qCWarning(LIBLEARNER_LOG) << "Cannot remove learning goal from model, not registered";
         return;
     }
     beginRemoveRows(QModelIndex(), index, index);
