@@ -1,5 +1,5 @@
 /*
- *  Copyright 2013-2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  Copyright 2013-2015  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
@@ -18,11 +18,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #include "application.h"
 
-#include "mainwindow.h"
-#include "core/profile.h"
+#include "core/skeleton.h"
 #include "core/course.h"
 #include "core/language.h"
 #include "core/resourcemanager.h"
@@ -31,9 +29,9 @@
 #include "core/phoneme.h"
 #include "core/phonemegroup.h"
 #include "core/trainingsession.h"
+#include "core/editorsession.h"
 #include "core/player.h"
 #include "core/recorder.h"
-#include "declarativeitems/applicationbackground.h"
 #include "models/coursemodel.h"
 #include "models/coursefiltermodel.h"
 #include "models/languagemodel.h"
@@ -42,6 +40,7 @@
 #include "models/unitmodel.h"
 #include "models/unitfiltermodel.h"
 #include "models/phrasemodel.h"
+#include "models/phraselistmodel.h"
 #include "models/phrasefiltermodel.h"
 #include "models/phonememodel.h"
 #include "models/phonemegroupmodel.h"
@@ -54,32 +53,33 @@
 #include "liblearnerprofile/src/learninggoal.h"
 #include "liblearnerprofile/src/models/learninggoalmodel.h"
 
-#include <kdeclarative.h>
-
-#include <qdeclarative.h>
+#include <QQmlComponent>
+#include <QQmlContext>
+#include <QQmlEngine>
+#include <KDeclarative/KDeclarative>
 #include <QGraphicsDropShadowEffect>
-#include <QScriptValue>
-#include <QScriptEngine>
 
-Application::Application()
-    : KApplication(true)
+Application::Application(int& argc, char** argv)
+    : QApplication(argc, argv)
 {
     registerQmlTypes();
 }
 
 void Application::registerQmlTypes()
 {
-    qmlRegisterType<Profile>("artikulate", 1, 0, "Profile");
+    qmlRegisterType<EditorSession>("artikulate", 1, 0, "EditorSession");
     qmlRegisterType<LearnerProfile::Learner>("artikulate", 1, 0, "Learner");
     qmlRegisterType<LearnerProfile::ProfileManager>("artikulate", 1, 0, "ProfileManager");
     qmlRegisterType<LearnerProfile::LearningGoal>("artikulate", 1, 0, "LearningGoal");
     qmlRegisterType<Unit>("artikulate", 1, 0, "Unit");
+    qmlRegisterType<Skeleton>("artikulate", 1, 0, "Skeleton");
     qmlRegisterType<Course>("artikulate", 1, 0, "Course");
     qmlRegisterType<Language>("artikulate", 1, 0, "Language");
     qmlRegisterType<ResourceManager>("artikulate", 1, 0, "ResourceManager");
     qmlRegisterType<Phrase>("artikulate", 1, 0, "Phrase");
     qmlRegisterType<Phoneme>("artikulate", 1, 0, "Phoneme");
     qmlRegisterType<PhonemeGroup>("artikulate", 1, 0, "PhonemeGroup");
+    qmlRegisterType<EditorSession>("artikulate", 1, 0, "EditorSession");
     qmlRegisterType<TrainingSession>("artikulate", 1, 0, "TrainingSession");
     qmlRegisterType<Player>("artikulate", 1, 0, "Player");
     qmlRegisterType<Recorder>("artikulate", 1, 0, "Recorder");
@@ -88,10 +88,11 @@ void Application::registerQmlTypes()
     qmlRegisterType<CourseFilterModel>("artikulate", 1, 0, "CourseFilterModel");
     qmlRegisterType<LanguageModel>("artikulate", 1, 0, "LanguageModel");
     qmlRegisterType<LanguageResourceModel>("artikulate", 1, 0, "LanguageResourceModel");
-    qmlRegisterType<LearningProgressModel>("artikulate", 1, 0, "LearningProgressModel");
+//     qmlRegisterType<LearningProgressModel>("artikulate", 1, 0, "LearningProgressModel");//TODO must be ported to new trainingsession
     qmlRegisterType<UnitModel>("artikulate", 1, 0, "UnitModel");
     qmlRegisterType<UnitFilterModel>("artikulate", 1, 0, "UnitFilterModel");
     qmlRegisterType<PhraseModel>("artikulate", 1, 0, "PhraseModel");
+    qmlRegisterType<PhraseListModel>("artikulate", 1, 0, "PhraseListModel");
     qmlRegisterType<PhraseFilterModel>("artikulate", 1, 0, "PhraseFilterModel");
     qmlRegisterType<PhonemeModel>("artikulate", 1, 0, "PhonemeModel");
     qmlRegisterType<PhonemeGroupModel>("artikulate", 1, 0, "PhonemeGroupModel");
@@ -99,7 +100,4 @@ void Application::registerQmlTypes()
     qmlRegisterType<ProfileModel>("artikulate", 1, 0, "ProfileModel");
     qmlRegisterType<SkeletonModel>("artikulate", 1, 0, "SkeletonModel");
     qmlRegisterType<LearnerProfile::LearningGoalModel>("artikulate", 1, 0, "LearningGoalModel");
-
-    qmlRegisterType<MainWindow>("artikulate", 1, 0, "MainWindow");
-    qmlRegisterType<ApplicationBackground>("artikulate", 1, 0, "ApplicationBackground");
 }
