@@ -1,5 +1,5 @@
 /*
- *  Copyright 2013  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  Copyright 2013-2015  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
@@ -36,10 +36,7 @@ class Skeleton;
 class Language;
 class Course;
 class ProfileManager;
-class KUrl;
-class QDomDocument;
-class QFile;
-class QXmlSchema;
+class QUrl;
 
 namespace LearnerProfile {
     class ProfileManager;
@@ -49,13 +46,14 @@ namespace LearnerProfile {
  * \class ResourceManager
  * This class loads and stores all data files of the application.
  */
-class ARTIKULATELIB_EXPORT ResourceManager : public QObject
+class ARTIKULATECORE_EXPORT ResourceManager : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(bool isRepositoryManager READ isRepositoryManager NOTIFY repositoryChanged);
+    Q_PROPERTY(QString repositoryUrl READ repositoryUrl NOTIFY repositoryChanged);
 
 public:
-    explicit ResourceManager(QObject *parent = 0);
+    explicit ResourceManager(QObject *parent = nullptr);
 
     /**
      * Load all course resources.
@@ -70,6 +68,16 @@ public:
      */
     void loadLanguageResources();
 
+    /**
+     * save all changes to course resources
+     */
+    void sync();
+
+    /**
+     * \return \c true if any course or skeleton is modified, otherwise \c false
+     */
+    bool modified() const;
+
     /**
      * Register loaded languages as learning goals in profile manager.
      *
@@ -83,6 +91,11 @@ public:
      */
     Q_INVOKABLE bool isRepositoryManager() const;
 
+    /**
+     * \return path to working repository, if one is set
+     */
+    QString repositoryUrl() const;
+
     /**
      * \return list of all available language specifications
      */
@@ -117,14 +130,14 @@ public:
      *
      * \param course the course to be update
      */
-    Q_INVOKABLE void updateCourseFromSkeleton(Course *course);
+    void updateCourseFromSkeleton(Course *course);
 
     /**
      * Add language to resource manager by parsing the given language specification file.
      *
      * \param languageFile is the local XML file containing the language
      */
-    void addLanguage(const KUrl &languageFile);
+    void addLanguage(const QUrl &languageFile);
 
     /**
      * Adds course to resource manager by parsing the given course specification file.
@@ -132,7 +145,7 @@ public:
      * \param courseFile is the local XML file containing the course
      * \return true if loaded successfully, otherwise false
      */
-    CourseResource * addCourse(const KUrl &courseFile);
+    CourseResource * addCourse(const QUrl &courseFile);
 
     /**
      * Adds course to resource manager. If the course's language is not registered, the language
@@ -150,12 +163,19 @@ public:
      */
     void removeCourse(Course *course);
 
+    /**
+     * Create new course for \p language and derived from \p skeleton.
+     *
+     * \return created course
+     */
+    Q_INVOKABLE Course * createCourse(Language *language, Skeleton *skeleton);
+
     /**
      * Adds skeleton resource to resource manager
      *
      * \param resource the skeleton resource to add to resource manager
      */
-    void addSkeleton(const KUrl &skeletonFile);
+    void addSkeleton(const QUrl &skeletonFile);
 
     /**
      * Adds skeleton resource to resource manager
@@ -177,9 +197,9 @@ public:
      */
     QList<SkeletonResource *> skeletonResources();
 
-    Q_INVOKABLE void newCourseDialog(Language* language = 0);
+    Q_INVOKABLE void newCourseDialog(Language* language = nullptr);
 
-signals:
+Q_SIGNALS:
     void languageResourceAdded();
     void languageResourceAboutToBeAdded(LanguageResource*,int);
     void languageResourceRemoved();
