@@ -1,5 +1,5 @@
 /*
- *  Copyright 2013  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  Copyright 2013-2015  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
@@ -21,31 +21,22 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#include <KXmlGuiWindow>
+#include <QQmlApplicationEngine>
+#include <KActionCollection>
 #include "core/resourcemanager.h"
-#include "core/trainingsession.h"
 
-class Profile;
-class KActionCollection;
-class KMenu;
-class QDeclarativeView;
+class TrainingSession;
+class KHelpMenu;
 
 namespace LearnerProfile {
     class ProfileManager;
 }
 
-class MainWindow : public KXmlGuiWindow
+class MainWindow : public QQmlApplicationEngine
 {
     Q_OBJECT
-    Q_PROPERTY(ResourceManager *globalResourceManager READ resourceManager CONSTANT)
 
 public:
-    Q_ENUMS(ViewMode)
-    enum ViewMode {
-        Trainer,
-        Editor
-    };
-
     /**
      * Default Constructor
      */
@@ -58,31 +49,25 @@ public:
 
     ResourceManager * resourceManager() const;
 
+    KActionCollection * actionCollection();
     void setupActions();
-
-    virtual QSize sizeHint() const { return QSize(1000, 700); }
-
     bool queryClose();
 
-public slots:
-    void showCourseEditor();
-    void closeCourseEditor();
-    void switchMode();
+public Q_SLOTS:
     void showSettingsDialog();
     void downloadNewStuff();
     void updateTrainingPhraseFont();
     void updateKcfgUseContributorResources();
     void configLearnerProfile();
-
-signals:
-     void modeChanged(bool);
+    void switchMenuBarVisibility();
+    void triggerAction(const QString &);
 
 private:
-    QDeclarativeView *m_view;
-    Profile *m_trainingProfile, *m_editorProfile;
+    KActionCollection *m_actionCollection;
+    KHelpMenu *m_helpMenu;
     ResourceManager *m_resourceManager;
     TrainingSession *m_trainingSession;
     LearnerProfile::ProfileManager *m_profileManager;
 };
 
-#endif // PAIRS_H
+#endif
